==> haskell-wcwidth-0.0.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wcwidth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wcwidth
version:              0.0.2
visibility:           public
id:                   wcwidth-0.0.2-Q7o0gad3qL3jVAzDoADIq
key:                  wcwidth-0.0.2-Q7o0gad3qL3jVAzDoADIq
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/wcwidth/
synopsis:             Native wcwidth.
description:
    Bindings for your system'\''s native wcwidth and a command line tool to examine
    the widths assigned by it. The command line tool can compile a width table
    to Haskell code that assigns widths to the Char type.

category:             Text
abi:                  c53828af8c7c723ecd978cea0abc17c5
exposed:              True
exposed-modules:      Data.Char.WCWidth
import-dirs:          /usr/lib/ghc-8.10.1/site-local/wcwidth-0.0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/wcwidth-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/wcwidth-0.0.2
hs-libraries:         HSwcwidth-0.0.2-Q7o0gad3qL3jVAzDoADIq
depends:              base-4.14.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-wcwidth/html/wcwidth.haddock
haddock-html:         /usr/share/doc/haskell-wcwidth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wcwidth-0.0.2-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wcwidth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wcwidth
version:              0.0.2
visibility:           public
id:                   wcwidth-0.0.2-C8wROecneCk1np8aYI6OyY
key:                  wcwidth-0.0.2-C8wROecneCk1np8aYI6OyY
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/wcwidth/
synopsis:             Native wcwidth.
description:
    Bindings for your system'\''s native wcwidth and a command line tool to examine
    the widths assigned by it. The command line tool can compile a width table
    to Haskell code that assigns widths to the Char type.

category:             Text
abi:                  9b3c06dcdcd6341aa7b8b238cc5ea3b2
exposed:              True
exposed-modules:      Data.Char.WCWidth
import-dirs:          /usr/lib/ghc-8.10.2/site-local/wcwidth-0.0.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/wcwidth-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/wcwidth-0.0.2
hs-libraries:         HSwcwidth-0.0.2-C8wROecneCk1np8aYI6OyY
depends:              base-4.14.1.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-wcwidth/html/wcwidth.haddock
haddock-html:         /usr/share/doc/haskell-wcwidth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
